//
// C++ Implementation: kpgdatatabledialog
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgdatatabledialog.h"


// include files for Qt
#include <qdatatable.h>
#include <qsqldatabase.h> // TODO: remove it when implement KPGCursor and KPGDataTable
#include <qsqlcursor.h>
#include <qlayout.h>

// include files for KDE
#include <klocale.h>
#include <kmessagebox.h>

// application specific includes
#include "../DbObjects/kpgconnection.h"


KPGDataTableDialog::KPGDataTableDialog(QWidget *parent, const char *name, KPGConnection *pConnection)
 : KPGDataTableDialogBase(parent, name)
{
  m_pDataTable = new QDataTable( this, "DataTable" );
  m_pDataTable->addColumn( "id", i18n( "Id" ) );
  m_pDataTable->addColumn( "id_transfer", i18n( "Id_transfer" ) );
  m_pDataTable->addColumn( "sms_id", i18n( "Sms_id" ) );
  m_pDataTable->addColumn( "msisdn", i18n( "Msisdn" ) );
  m_pDataTable->addColumn( "msisdn_gw", i18n( "Msisdn_gw" ) );
  m_pDataTable->addColumn( "tarif", i18n( "Tarif" ) );
  m_pDataTable->addColumn( "id_message_state", i18n( "Id_message_state" ) );
  m_pDataTable->addColumn( "message", i18n( "Message" ) );
  m_pDataTable->addColumn( "reply", i18n( "Reply" ) );
  m_pDataTable->addColumn( "reply_id", i18n( "Reply_id" ) );
  m_pDataTable->setSorting( TRUE );
  m_pDataTable->setSelectionMode( QDataTable::Single );
  m_pDataTable->setConfirmDelete( TRUE );
  m_pDataTable->setAutoEdit(TRUE);
    
  KPGDataTableDialogBaseLayout->addWidget( m_pDataTable, 0, 0 );
  
  //--- Init Qt DB layer
  QSqlDatabase *db = QSqlDatabase::addDatabase("QPSQL7");
  db->setDatabaseName(pConnection->dbname());
  db->setUserName(pConnection->username());
  db->setPassword(pConnection->password());
  db->setHostName(pConnection->hostname());
  QString strPort(pConnection->port()); 
  db->setPort(strPort.toInt());
  
  if ( !db->open() ) 
  {
    qWarning( "Failed to open database: " +
    db->lastError().driverText() );
    qWarning( db->lastError().databaseText() );
    return;
  }
    
  displayData(); 
}


KPGDataTableDialog::~KPGDataTableDialog()
{
}

void KPGDataTableDialog::displayData()
{
  if ( m_pDataTable ) 
  {
    QSqlCursor* cursor = m_pDataTable->sqlCursor();
        
    if ( !cursor ) 
    {
      cursor = new QSqlCursor( "message" );
      if ( m_pDataTable->isReadOnly() ) 
      {
      cursor->setMode( QSqlCursor::ReadOnly );
      KMessageBox::sorry(this, i18n("read only"));
    }
    else
      cursor->setMode( QSqlCursor::Writable ); // allow insert/update/delete    
          
    QSqlIndex pkIndex = cursor->index("id");
    cursor->setPrimaryIndex( pkIndex );
            
    m_pDataTable->setSqlCursor( cursor, FALSE, TRUE );
    }
    
    if ( !cursor->isActive() )
      m_pDataTable->refresh( QDataTable::RefreshAll );
    }
}

#include "kpgdatatabledialog.moc"
